==> brlcad-7.22.0.tar.bz2: brlcad-7.22.0/src/conv/step/BrepWithVoids.h <==
/*                 ManifoldSolidBrep.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2012 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file ManifoldSolidBrep.h
 *
 * Class definition used to convert STEP "ManifoldSolidBrep" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef BREPWITHVOIDS_H_
#define BREPWITHVOIDS_H_

#include "ManifoldSolidBrep.h"

// forward declaration of class
class OrientedClosedShell;
class STEPWrapper;
class ON_Brep;

typedef list<OrientedClosedShell *> LIST_OF_ORIENTED_CLOSED_SHELLS;

class BrepWithVoids: public ManifoldSolidBrep {
private:
    static string entityname;

protected:
    LIST_OF_ORIENTED_CLOSED_SHELLS voids;

public:
    BrepWithVoids();
    BrepWithVoids(STEPWrapper *sw, int step_id);
    virtual ~BrepWithVoids();
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual bool LoadONBrep(ON_Brep *brep);
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* BREPWITHVOIDS_H_ */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */

==> brlcad-7.24.0.tar.bz2: brlcad-7.24.0/src/conv/step/BrepWithVoids.h <==
/*                 ManifoldSolidBrep.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2013 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file ManifoldSolidBrep.h
 *
 * Class definition used to convert STEP "ManifoldSolidBrep" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef BREPWITHVOIDS_H_
#define BREPWITHVOIDS_H_

#include "ManifoldSolidBrep.h"

// forward declaration of class
class OrientedClosedShell;
class STEPWrapper;
class ON_Brep;

typedef list<OrientedClosedShell *> LIST_OF_ORIENTED_CLOSED_SHELLS;

class BrepWithVoids: public ManifoldSolidBrep
{
private:
    static string entityname;
    static EntityInstanceFunc GetInstance;

protected:
    LIST_OF_ORIENTED_CLOSED_SHELLS voids;

public:
    BrepWithVoids();
    BrepWithVoids(STEPWrapper *sw, int step_id);
    virtual ~BrepWithVoids();
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual bool LoadONBrep(ON_Brep *brep);
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* BREPWITHVOIDS_H_ */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */
